// **********************************************************************
//
//                           EXLP
//
//  This program reads a maximization problem from an MPS file, sets
//  the appropriate control variable to indicate that it is a
//  maximization problem, solves the problem with the simplex method,
//  and prints the solution.
//
// **********************************************************************

#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <assert.h>
#include "ekk_c_api.h"

void main()
{
    // Initialize OSL environment    
    EKKContext * env;
    env = ekk_initializeContext();

    // Create an OSL model "test"    
    EKKModel * test;
    test=ekk_newModel(env,NULL);

    // Set to maximization problem   
    int rtcod = ekk_setRmaxmin(test,-1.000000);

    // Read model data from MPS file 
    rtcod = ekk_importModel(test,"exlp1.mps");

    // Scale the model data          
    rtcod = ekk_scale(test);

    // Solve using simplex method    
    rtcod = ekk_primalSimplex(test,2);

    // Print the solution            
    rtcod = ekk_printSolution(test);

    // Delete the model              
    rtcod = ekk_deleteModel(test);

    // OSL Destructor                
    ekk_endContext(env);
}
