// -------------------------------------------------------------------
//                             EXNFES
//  This program reads an infeasible LP problem from an MPS file and
//  solves it using the primal simplex method.  Then, it analyzes the
//  row/column infeasibilities to generate an IIS (Irreducible Infeasible
//  Subset) of rows and columns.
// ------------------------------------------------------------------- 

#include <string.h>
#include <stdlib.h>
#include <math.h>
#include "ekk_c_api.h"

void main()
{
    // Initialize OSL environment 
    EKKContext * env;
    env = ekk_initializeContext();

    // Create an OSL model "test" 
    EKKModel * test;
    test=ekk_newModel(env,NULL);

    // Set to print nonzero solutions only 
    int rtcod = ekk_setIsolmask(test,6);

    // Read model data from MPS file 
    rtcod = ekk_importModel(test,"box1.mps");

    // Scale the model data 
    rtcod = ekk_scale(test);

    // Solve using simplex method 
    rtcod = ekk_primalSimplex(test,2);

    int index[9];
    index[0] = 2*ekk_getInumcols(test) + 2*ekk_getInumrows(test);
    int * table = new int[index[0]];

    // Analyze infeasibilities 
    rtcod = ekk_infeasibilities(test,8,3,index,table);

    // Print row and columns found to be in the IIS
    if ( index[1]!=-1 ) {
      printf("row numbers of rows whose lower bounds are members of the IIS\n");
      for ( int i=index[1]; i<=index[2]; ++i )
        printf("%d\n",table[i]); 
    }
    if ( index[3]!=-1 ) {
      printf("row numbers of rows whose upper bounds are members of the IIS\n");
      for ( int i=index[3]; i<=index[4]; ++i )
        printf("%d\n",table[i]); 
    }
    if ( index[5]!=-1 ) {
      printf("column numbers of columns whose lower bounds are members of the IIS\n");
      for ( int i=index[5]; i<=index[6]; ++i )
        printf("%d\n",table[i]); 
    }
    if ( index[7]!=-1 ) {
      printf("column numbers of columns whose upper bounds are members of the IIS\n");
      for ( int i=index[7]; i<=index[8]; ++i )
        printf("%d\n",table[i]); 
    }
    
    delete [] table;

    // Print the solution 
    rtcod = ekk_printSolution(test);

    // Delete the model 
    rtcod = ekk_deleteModel(test);
  
    // OSL Destructor
    ekk_endContext(env); 
}
