// -------------------------------------------------------------------
//                             EXQBAR
//
//  This program reads a quadratic problem from MPS files, solves
//  the problem using the quadratic barrier solver, and prints the
//  solution.
//
// -------------------------------------------------------------------
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <assert.h>
#include "ekkc.h"
#include "ekk_c_api.h"


void main()
{
    // Initialize OSL environment 
    EKKContext * env;
    env = ekk_initializeContext();

    // Create an OSL model "test" 
    EKKModel * test = ekk_newModel(env,NULL);

    // Read linear model data from MPS file 
    int rtcod = ekk_importModel(test,"share2qp.mps");

    // Set maximum allowable barrier iterations 
    rtcod = ekk_setImaxiterb(test,100);

    // Turn off printing of a warning message 
    rtcod = ekk_messagePrintOff(test,3081);

    // Turn off printing of a warning message 
    rtcod = ekk_messagePrintOff(test,3084);

    // Set to compress the matrix after presolving 
    ekk_setCompressOn(test);

    // Scale the linear model data 
    rtcod = ekk_scale(test);

    // Presolve the linear model data 
    rtcod = ekk_preSolve(test,3,"presolve33");

    // Read quadratic model data from MPS file 
    rtcod = ekk_importQuadraticData(test,"share2qp.mps");

    // Set GAMMA regularization tolerance 
    rtcod = ekk_setRregularizedGamma(test,1.0e-6);

    // Set DELTA regularization tolerance 
    rtcod = ekk_setRregularizedDelta(test,1.0e-6);

    // Solve using quadratic barrier method 
    rtcod = ekk_quadraticBarrier(test,0);

    // Postsolve the linear model data 
    rtcod = ekk_postSolve(test,"presolve33");

    // Delete temporary file 
    remove("presolve33");

    // Set to print primal and dual solutions 
    rtcod = ekk_setIprtinfomask(test,63);

    // Print the solution 
    rtcod = ekk_printSolution(test);

    // Delete the model 
    rtcod = ekk_deleteModel(test);

    // OSL Destructor 
    ekk_endContext(env);
}
