// ***********************************************************************
//
//
//  Minimize Z = x1 + 2x5 - x8 +
//               1/2(x1**2 + x2**2 + x3**2 + x4**2 +
//                   x5**2 + x6**2 + x7**2 + x8**2)
//
//  subject to:
//
//  2.5 <=   3x1 +  x2          - 2x4 - x5              -    x8
//                 2x2 + 1.1x3                                  <=  2.1
//                          x3             + x6                  =  4.0
//  1.8 <=                      2.8x4            -1.2x7         <=  5.0
//  3.0 <= 5.6x1                      + x5              + 1.9x8 <= 15.0
//
//  and subject to:
//
//  2.5 <= x1
//    0 <= x2 <= 4.1
//    0 <= x3
//    0 <= x4
//  0.5 <= x5 <= 4.0
//    0 <= x6
//    0 <= x7
//    0 <= x8 <= 4.3
//
// **********************************************************************

#include <stdlib.h>
#include "ekk_c_api.h"

#define INF 1.0e30


int ncol  =  8;     // no. of columns in the constraint matrix
int nrow  =  5;     // no. of rows in the constraint matrix
int nels  =  14;    // no. of elements in the constraint matrix

                    // Row indices
int    mrow[]  = {0,4,0,1,1,2,0,3,0,4,2,3,0,4};

                    // Column indices
int    mcol[]  = {0,0,1,1,2,2,3,3,4,4,5,6,7,7};

                    // Matrix elements
double  dels[] = {3.0,5.6,1.0,2.0,1.1,1.0,-2.0,2.8,-1.0,
                  1.0,1.0,-1.2,-1.0,1.9};

                    // Lower bounds on row activities
double  drlo[] = {2.5,-1.0e+31,4.0,1.8,3.0};

                    // Upper bounds on row activities
double  drup[] = {1.0e+31,2.1,4.0,5.0,1.5e+1};

                    // Lower bounds on columns
double  dclo[] = {2.5,0.0,0.0,0.0,0.5,0.0,0.0,0.0};

                    // Upper bounds on columns
double  dcup[] = {1.0e+31,4.1,1.0e+31,1.0e+31,4.0,1.0e+31,
                  1.0e+31,4.3};

                    // LINEAR Objective function coefficients
double  dobj[] = {1.0,0.0,0.0,0.0,2.0,0.0,0.0,-1.0};

                    // QUADRATIC Objective function coefficients
double  dqdg[] = {1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0};

                    // Column indices of qudratic components
int    mdiag[]={0,1,2,3,4,5,6,7};

void main( long argc, char *argv[] ) {

    // Initialize OSL environment 
    EKKContext * env;
    env = ekk_initializeContext();

    // Create a model
    EKKModel *test = ekk_newModel(env,NULL);

    // Load row/column bounds, obj function
    int rtcod = ekk_loadRimModel(test,nrow,drlo,drup,ncol,dobj,dclo,dcup);

    // Delete model's last block
    rtcod = ekk_dropLastElementBlock(test);

    // Add a block of elements to model
    rtcod = ekk_addElementBlock(test, nels, mrow, mcol, dels);

    // Merge all blocks in model into 1 block
    rtcod = ekk_mergeBlocks(test,1);

    // Load quadratic matrix
    rtcod = ekk_loadQuadraticData(test, 1, ncol, mdiag, mdiag, dqdg);

    // Solve using quadratic simplex algorithm
    rtcod = ekk_quadraticSimplex(test,1);

    // Print the solution
    rtcod = ekk_printSolution(test);

    // Destroy the model
    rtcod = ekk_deleteModel(test);

    // OSL Destructor
    ekk_endContext(env);
}
