// -------------------------------------------------------------------
//                          EXQMIP
//  This program reads a minimization problem from an MPS file, then
//  registers a Call Back function to alter the solves the problem
//  with the branch and bound method, and lastly prints the results.
// --------------------------------------------------------------------
#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <assert.h>
#include "ekk_c_api.h"

// User Exit 
void QMIPSLVU (EKKModel * m, int  reason,
               double * objective,  int  * status)
{
    printf("\n **** Entering QMIPSLVU with Reason=%d\n",reason);
    if (ekk_isModelQuadratic(m)) {
        printf("\n **** Model is quadratic \n");

        if (reason==1) ekk_primalQuadraticSimplex(m,1);

    else ekk_dualQuadraticSimplex(m,0);
    } else {
          if (reason==1) ekk_primalSimplex(m,1);
          else ekk_dualSimplex(m);
    }

    // Get problem status after solving 
    *status = ekk_getIprobstat(m);

    // Get objective function value 
    *objective = ekk_getRobjvalue(m);
    printf("\n **** Obj=%f, Status=%d ****\n",*objective,*status);

} // QMIPSLVU for EXQMIP 

void main()
{
    // Initialize OSL environment 
    EKKContext * env;
    env = ekk_initializeContext();

    // Create a model 
    EKKModel * qmipmodel;
    qmipmodel = ekk_newModel(env,NULL);

    // Read linear model data from MPS file 
    const char * mpsFile="exqmip2.mps";
    int rtcod = ekk_importModel(qmipmodel,mpsFile);

    // Read quadratic model data from MPS file 
    rtcod = ekk_importQuadraticData(qmipmodel,mpsFile);

    // Register CallBack QMIPSLVU 
    ekk_registerSlvuCallBack(qmipmodel,(ekkcbslvu) QMIPSLVU);

    // Solve by branch-and-bound 
    rtcod = ekk_branchAndBound(qmipmodel,NULL,NULL);

    // Print solution 
    rtcod = ekk_printSolution(qmipmodel);

    // Destroy the model 
    rtcod = ekk_deleteModel(qmipmodel);

    // OSL Destructor 
    ekk_endContext(env);
}
